@@ -30,6 +30,11 @@ sub priority()
     return $MediaCloud::JobManager::Job::MJM_JOB_PRIORITY_LOW;
 }
 
+sub lazy_queue()
+{
+    return 1;
+}
+
 sub configuration()
 {
     my $configuration = MediaCloud::JobManager::Configuration->new();
