@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use Moose::Role;
-with 'MediaCloud::JobManager::Job' => { -excludes => [ 'configuration' ], };
+with 'MediaCloud::JobManager::Job' => { -excludes => [ 'configuration', 'lazy_queue' ], };
 
 use Data::Dumper;
 
@@ -21,4 +21,9 @@ sub configuration
     return $configuration;
 }
 
+sub lazy_queue()
+{
+    die "Lazy queues are not supported in Gearman.";
+}
+
 1;
